@@ -2,7 +2,7 @@
 
 LEAD_COLUMN_MAP = {'first_name': ['first', 'fn', 'firstname'],
                    'last_name': ['last', 'ln', 'lastname'],
-                   'phone_number': ['phone', 'cell', 'phonenumber'],
+                   'phone_number': ['phone', 'cell', 'phonenumber', 'cell_phone', 'cellphone'],
                    'email': ['email_address', 'emailaddress'],
                    'follow_up': ['followup']
                    }
